
Documentation
-------------

SNMP Simulator suite contains a handful of command-line tools implementing
different stages of simulation work flow.

In general, SNMP simulator user might want to prepare some SNMP simulation
data in one way or the other, then run SNMP agent simulator tool over
simulation data to represent SNMP agents on the network. Then user software
might query those simulated agents to test its own behavior.

.. toctree::
   :maxdepth: 2

   command-line-options
   simulating-agents
   managing-simulation-data
   addressing-agents
   simulation-with-variation-modules
   building-simulation-data
   recording-with-variation-modules
   tips-and-tricks

